hurst(x, y = NULL, z = NULL, data,
gridtriple = FALSE, sort = TRUE,
block.sequ = unique(round(exp(seq(log(3000), log(dim[1]),
len=min(100, dim[1]))))),
fft.m = c(1, min(1000, (fft.len - 1) / 10)),
fft.max.length = Inf, method=c("dfa", "fft", "var"),
mode=c("plot", "interactive"), pch=16, cex=0.2, cex.main=0.85,
PrintLevel=RFparameters()$Print,height=3.5,...)grid==TRUE.
If gridtriple==TRUE
then x, y, and z are of the
form c(start,end,step); if
gridtriple==FALSE then xTRUE then the coordinates are permuted
such that the largest grid length is in x-direction; this is
of interest for algorithms that slice higher dimensional fields
into one-dimensional sections.x-direction is
larger than fft.max.length then the segments of length
fft.max.length are considered, shifted by
fft.max.length/2 (WOSA-estimator).pch.PrintLevel is 0 or 1
nothing is printed.
If PrintLevel==2 warnings and the regression results
are given. If PrintLevel>2 tracing information is given.dfa, varmeth, fft corresponding to
the three methods given in the Details.
Each of the elements is itself a list that contains the
following elements.NULL or the restricted x-coordinates given
by the user in the interactive plotNULL or y-coordinates according to x.uNULL or the coefficients of
x.u and y.uNULL or the Hurst coefficient corresponding to the
user's regression lineThe function calculates the Hurst coefficient by various methods:
aggregated variation
periodogram