CovarianceFct returns the values of a covariance function
Variogram returns the values of a variogram model PrintModelList prints the list of currently implemented models
including the corresponding simulation methods
GetModelList returns a matrix of currently implemented models
and their simulation methods
GetModelNames returns a list of currently implemented models
CovarianceFct(x, model, param, dim=ifelse(is.matrix(x),ncol(x),1),
fctcall="Covariance")Variogram(x, model, param, dim=ifelse(is.matrix(x),ncol(x),1))
PrintModelList()
GetModelList(abbr=TRUE)
GetModelNames()
dim=1 then x
is a vector.PrintModelList() for
all options; see Details for the definition of the model by a list.param is vector of the form
param=c(NA,variance,nugget,scale,...), in this order;
The dots ... stand for addTRUE the names for the methods are
abbreviated. If numerical, abbr gives the number of letters.bessel$$C(x)=2^a \Gamma(a+1)x^{-a} J_a(x)$$The parameter$\kappa$is greater than or equal to$\frac{d-2}2$, where$d$is the
dimension of the random field.fractalBwavecauchy$$C(x)=\left(1+x^2\right)^{-\kappa}$$The parameter$\kappa$is positive.
The model possesses two generalisations, thegencauchymodel and thehyperbolicmodel.cauchytbm$$C(x)=\left(1+\left(1-\frac{\kappa_2}{\kappa_3}
\right)x^{\kappa_1}\right)
\left(1+x^{\kappa_1}\right)^{-\frac{\kappa_2}{\kappa_1}-1}$$The parameter$\kappa_1$is in (0,2] and$\kappa_2$is positive.
The model is valid for dimensions$d\le\kappa_3$;
this has been shown for integer$\kappa_3$, but the
package allows real values of$\kappa_3$.
It allows for simulating random fields where
fractal dimension and Hurst coefficient can be chosen
independently.
It has negative correlations for$\kappa_2>1$and large$x$.circular$$C(x)=
\left(1-\frac 2\pi
\left(x \sqrt{1-x^2} +
\arcsin(x)\right)\right)
1_{[0,1]}(x)$$This isotropic covariance function is valid only for dimensions
less than or equal to 2.constant
Identically constant. Any scale parameter is ignored.cone
This model is used only for methods based on marked point processes
(seecubic$$C(x)=(1- 7x^2+8.75x^3-3.5x^5+0.75 x^7)1_{[0,1]}(x)$$This model is valid only for dimensions less than or equal to 3.
It is a 2 times differentiable covariance functions with compact
support. %(See Chiles&Delfiner, 1998)cutoff(hypermodel, see also below)$$C(x)=\phi(xB), 0\le xA \le \kappa_2$$$$C(x)=b_1 (r^{\kappa_3} - xB)^{2 \kappa_3}, \kappa_2\le xA \le
\kappa_2\kappa_3$$$$C(x)=0, \kappa_2\kappa_3\le xA$$The cutoff model is a functional of the covariance function$\phi$. Since the model itself is indifferent for
scale or anisotropy parameters, the latter must be given only
for the submodels.
See below for general comments on hypermodels.
The first parameter,$\kappa_1$, gives the number of
subsequent models that build$\phi$;$\kappa_2\ge0$,$\kappa_3>0$.
The parameters$r$and$b_0$are chosen internally such that$C$is a smooth function.
The parameters$A$and$B$are the inverse scale parameters for
the hypermodel and submodel, respectively. Note thatcutoffseldemly
works, if$A$and$B$are not identical. The algorithm that checks the given parameters knows
only about some few necessary conditions.
Hence it is not ensured that
the cutoff-model is a valid covariance function for any
choice of phi and the parameters.
For certain models$\phi$, i.e.stable,whittleandgencauchy, some sufficient conditions
are known.
% \item \code{dagum} % \deqn{C(x)=1 - ( 1 + x^{-\kappa_2})^{-\kappa_1}}{ % C(x)=1 - ( 1 + x^-b)^(-a)} % This model is valid in dimensions up to 3 for % \eqn{\kappa_1 \in (0,1)}{a in (0,1)} and % \eqn{\kappa_2 \in (0,2]}{b in (0,2]}.
dampedcosine$$C(x)=e^{-\kappa x} \cos(x), \quad x\ge0$$This model is valid
for dimension 1 iff$\kappa\ge1$,
for dimension 2 iff$\kappa\ge1$,
and for dimension 3 iff$\kappa\ge \sqrt{3}$.exponential$$C(x)=e^{-x}, \quad x\ge0$$This model is a special case of thewhittlematernmodel
(for$\kappa=\frac12$there)
and thestableclass (for$\kappa=1$).fractalB(fractal Brownian motion)$$\gamma(x) = x^\kappa$$The parameter$\kappa$is in$(0,2]$.
(Implemented for up to three dimensions)FD$$C(k) = \frac{(-1)^k \Gamma(1-\kappa/2)^2}{\Gamma(1-\kappa/2+k)
\Gamma(1-\kappa/2-k),
\qquad k \in {\bf N}}$$and linearly interpolated otherwise.
Here,$\Gamma$is the Gamma function.
The parameter$\kappa$is in$[-1, 1)$.
The model is defined in 1 dimension only.
Remark: the fractionally differenced process
stems from time series modelling
where the grid locations are multiples
of the scale parameter.fractgauss$$C(x) = 0.5 (|x+1|^{\kappa_1} - 2|x|^{\kappa_1} +
|x-1|^{\kappa_1})$$This model is the covariance function for the fractional Gaussian noise
with Hurst parameter$H=\kappa_1 /2$,$\kappa_1 \in
(0,2]$gauss$$C(x)=e^{-x^2}$$This model is a special case of thestableclass
(for$\kappa=2$there).
Note that the corresponding function for the random coins
method (cf. the methods based on marked point processes ingneitingfor an alternative model that does not have
the disadvantages of the Gaussian model.gencauchy(generalisedcauchy)
$$C(x)=(1+x^{\kappa_1})^{-\kappa_2/\kappa_1}$$The parameter$\kappa_1$is in (0,2], and$\kappa_2$is positive.
This model allows for simulating random fields where
fractal dimension and Hurst coefficient can be chosen
independently.gengneiting(generalisedgneiting)
if$\kappa_1=1$then$$C(x)=\left(1+(\kappa_2+1)x\right) * (1-x)^{\kappa_2+1}
1_{[0,1]}(x)$$if$\kappa_1=2$then$$C(x)=\left(1+(\kappa_2+2)x+\left((\kappa_2+2)^2-1\right)x^2/3\right)
(1-x)^{\kappa_2+2} 1_{[0,1]}(x)$$if$\kappa_1=3$then$$C(x)=\left(1+(\kappa_2+3)x+\left(2(\kappa_2+3)^2-3\right)x^2/5
+\left((\kappa_2+3)^2-4\right)(\kappa_2+3)x^3/15\right)(1-x)^{\kappa_2+3}
1_{[0,1]}(x)$$The parameter$\kappa_1$is a positive integer; here only the
cases$\kappa_1=1, 2, 3$are implemented.
The parameter$\kappa_2$is greater than or equal to$(d + 2\kappa_1 +1)/2$where$d$is the
dimension of the random field.% the differentiability is ??
gneiting$$C(x)=\left(1 + 8 sx + 25 (sx)^2 + 32
(sx)^3\right)(1-sx)^8 1_{[0,1]}(sx)$$where$s=0.301187465825$.
This isotropic covariance function is valid only for dimensions less
than or equal to 3.
It is a 6 times differentiable covariance functions with compact
support.
It is an alternative to thegaussianmodel since
its graph is visually hardly distinguishable from the graph of
the Gaussian model, but possesses neither the mathematical and nor the
numerical disadvantages of the Gaussian model.
This model is a special case ofgengneiting(for$\kappa_1=3$and$\kappa_2=5$there).
Note that, in the original work by Gneiting (1999),$s=\frac{10\sqrt2}{47}\approx 0.3$, a numerical value slightly deviating from the
optimal one.hyperbolic$$C(x)=\frac{1}{\kappa_3^{\kappa_2}
K_{\kappa_2}(\kappa_1 \kappa_3)}
\left(\kappa_3^2 +x^2\right)^{{\kappa_2}/2}
K_{{\kappa_2}}\left(
\kappa_1 \left(\kappa_3^2 + x^2\right)^{1/2}\right), \quad
x>0$$The parameters are such that
$\kappa_3\ge0$,$\kappa_1>0$and$\kappa_2>0,\quad$or
$\kappa_3>0$,$\kappa_1>0$and$\kappa_2=0,\quad$or
$\kappa_3>0$,$\kappa_1\ge0$, and$\kappa_2<0$. note="" that="" this="" class="" is="" over-parametrised;="" always="" one="" of="" the="" three="" parameters$\kappa_1$,$\kappa_3$,="" and="" scale="" can="" be="" eliminated="" in="" formula.="" therefore,="" these="" parameters="" should="" kept="" fixed="" any="" simulation="" study.="" model="" contains="" as="" special="" cases="" thewhittlematernmodel and thecauchymodel, for$\kappa_3=0$and$\kappa_1=0$, respectively.0$.>iacocesare$$C(x, t)=(1+\|x\|^{\kappa_1}+|t|^{\kappa_2})^{-\kappa_3}$$The parameters$\kappa_1$and$\kappa_2$take values
in$[1,2]$; the parameters$\kappa_3$must be greater
than or equal to half the space-time dimension.besselwhittlematernpower(a=1there).lgd1(local-global distinguisher)$$C(x)=
1-\frac\beta{\alpha+\beta}|x|^{\alpha}, |x|\le 1 \qquad \hbox{and} \qquad
\frac\alpha{\alpha+\beta}|x|^{-\beta}, |x|> 1$$Here$\beta>0$and$\alpha$is in$(0, \frac12 (3 - d)]$for dimension$d=1,2$.
The random field has fractal dimension$d + 1 - \frac\alpha2$and Hurst coefficient$1 - \frac\beta2$for$\beta\in(0,1]$mastein(hypermodel for non-separabel space time modelling)$$C(x, t)=\frac{\Gamma(\kappa_2 + \gamma(t))\Gamma(\kappa 2 +
\kappa_3)}{ \Gamma(\kappa_2 +
\gamma(t) + \kappa_3) \Gamma(\kappa_2)}
W_{\kappa_2 + \gamma(t)}(\|x - Vt\|)$$$\Gamma$is the Gamma function;$\gamma$is a variogram;$W$is the Whittle-Matern model.
The first parameter,$\kappa_1$, gives the number of
subsequent models that build$\gamma$. Here, the
names of covariance models can also be used; the algorithm
chooses the corresponding variograms then.
The parameter$\kappa$is the smoothness parameter
of the Whittle-Matern model (for$t=0$) and must be positive.
Finally,$c$must be greater than or equal to half the
dimension of$x$.
Instead of the velocity parameter$V$, the anisotropy matrix
for the hyper model is chosen appropriately. Note that
the anisotropy matrix must be such that$(x,t) is transformed
into a purely spatial vector, i.e. the entries in
last column of the matrix are all naught.
On the other hand, all entries of the
anisotropy matrices in the submodels that build \eqn{\gamma}{gamma}
is naught except the very last, purely temporal one.Note, that for numerical reasons, \eqn{b + g(t)} may not exceed the value 80.0. If exceeded \code{NA} is returned or the algorithm fails. \item matern\cr See \code{whittlematern}. \item \code{nsst} (Non-Separable Space-Time model) \deqn{C(x,t)= \psi(t)^{-\kappa_6} \phi(x / \psi(t))}{C(x,t)= psi(t)^{-f} \phi(x / psi(t))} This model is used for space-time modelling where the spatial component is isotropic.\cr \eqn{\phi} is the \code{stable} model if \eqn{\kappa_2=1}{b=1};\cr \eqn{\phi} is the \code{whittlematern} model if \eqn{\kappa_2=2}{b=2};\cr \eqn{\phi} is the \code{cauchy} model if \eqn{\kappa_2=3}{b=3};\cr Here, \eqn{kappa_1}{a} is the respective parameter for the model; the restrictions on \eqn{kappa_1}{a} are described there.
The function \eqn{\psi}{psi} satisfies\cr \eqn{\psi^2(t) = (t^{\kappa_3}+1)^{\kappa_4}}{psi^2(t) = (t^c+1)^d} if \eqn{\kappa_5=1}{e=1}\cr \eqn{\psi^2(t) = \frac{\kappa_4^{-1}t^{\kappa_3}+1}{t^{\kappa_3}+1} }{psi^2(t) = (d^{-1} t^c+1)/(t^c+1)} if \eqn{\kappa_5=2}{e=2}\cr \eqn{\psi^2(t) = -\log(t^{\kappa_3}+\kappa_4^{-1})/ \log\kappa_4}{psi^2(t) = -\log(t^c+1/d)/log d} if \eqn{\kappa_5=3}{e=3}\cr The parameter \eqn{\kappa_6}{f} must be greater than or equal to the genuine spatial dimension of the field. Furthermore, \eqn{\kappa_3\in (0,2]}{c in (0,2]} and \eqn{\kappa_4\in (0,1)}{d in (0,1)}. The spatial dimension must be \code{>=1}. \item \code{nsst2} \deqn{C(x,t)= \psi(t)^{-\kappa_7} \phi(x /\psi(t))}{C(x,t)= psi(t)^{-g} \phi(x / psi(t))} This model is used for space-time modelling where the spatial component is isotropic. Here\cr \eqn{\phi} is the \code{gencauchy} model if \eqn{\kappa_3=1}{c=1}.\cr The parameters \eqn{kappa_1}{a} and \eqn{kappa_2}{b} are the respective parameters for the model. The function \eqn{\psi}{psi} satisfies\cr \eqn{\psi^2(t) = (t^{\kappa_4}+1)^{\kappa_5}}{psi^2(t) = (t^d+1)^e} if \eqn{\kappa_6=1}{f=1}\cr \eqn{\psi^2(t) = \frac{\kappa_5^{-1}t^{\kappa_4}+1}{t^{\kappa_4}+1} }{psi^2(t) = (e^{-1} t^d+1)/(t^d+1)} if \eqn{\kappa_6=2}{f=2}\cr \eqn{\psi^2(t) = -\log(t^{\kappa_4}+\kappa_5^{-1})/ \log\kappa_5}{psi^2(t) = -\log(t^d+1/e)/log e} if \eqn{\kappa_6=3}{f=3}\cr The parameter \eqn{\kappa_7}{g} must be greater than or equal to the genuine spatial dimension of the field. Furthermore, \eqn{\kappa_4\in (0,2]}{d in (0,2]} and \eqn{\kappa_5\in (0,1]}{e in (0,1]}. Necessarily, \code{dim>=2}. The spatial dimension must be \code{>=1}.
\item \code{nugget} \deqn{C(x)=1_{{0}}(x)}{1(x==0)} If the model is used in \code{param}-definition mode, either \code{param[2]}, the \code{variance}, or \code{param[3]}, the \code{nugget}, must be zero. If the model is used in the list-definition mode, the anisotropy matrix must be given in an anisotropic context, but not the scale parameter in an isotropic context. \item \code{penta} \deqn{C(x)= \left(1 - \frac{22}3 x^2 +33 x^4 - \frac{77}2 x^5 + \frac{33}2 x^7 -\frac{11}2 x^9 + \frac 56 x^{11} \right)1_{[0,1]}(x)}{C(x)= 1 - 22/3 x^2 +33 x^4 - 77/2 x^5 + 33/2 x^7 - 11/2 x^9 + 5/6 x^11 if 0<=x<=1, 0="" 4="" otherwise}="" valid="" only="" for="" dimensions="" less="" than="" or="" equal="" to="" 3.="" this="" is="" a="" times="" differentiable="" covariance="" functions="" with="" compact="" support.="" \item="" \code{power}="" \deqn{c(x)="(1-x)^\kappa" 1_{[0,1]}(x)}{c(x)="(1-x)^a" if="" 0<="x<=1," function="" dimension="" \eqn{d}{d}="" \eqn{\kappa\ge\frac{d+1}2}{a="">= (d+1)/2}. For \eqn{\kappa=1}{a=1} we get the well-known triangle (or tent) model, which is valid on the real line, only. \item powered exponential\cr See \code{stable}. \item \code{qexponential} \deqn{C(x)=\frac{2 e^{-x}-\kappa e^{-2x}}{2-\kappa}}{ C(x) = (2 exp(-x)-a exp(-2x))/(2-a)} The parameter \eqn{\kappa}{a} takes values in \eqn{[0,1]}{[0,1]}. \item \code{spherical} \deqn{C(x)=\left(1- \frac32 x+\frac 12 x^3\right) 1_{[0,1]}(x)}{C(x)= 1 - 1.5 x + 0.5 x^3 if 0<=x<=1, 0="" otherwise}="" this="" isotropic="" covariance="" function="" is="" valid="" only="" for="" dimensions="" less="" than="" or="" equal="" to="" 3.<="" p="">
\item \code{stable} \deqn{C(x)=\exp\left(-x^\kappa\right)}{C(x)=exp(-x^a)} The parameter \eqn{\kappa}{a} is in \eqn{(0,2]}{(0,2]}. See \code{exponential} and \code{gaussian} for special cases.
\item \code{Stein} (hypermodel, see also below) \deqn{C(x)=a_0 + a_2 (xB)^2 + \phi(xB), 0\le x \le \kappa_2}{C(x) = a_0 + a_2 (xB)^2 + phi(xB), 0 <= xa="" <="b}" \deqn{c(x)="b_1" (\kappa_3="" -="" xb)^3="" (xb),="" \kappa_2\le="" \le="" \kappa_2\kappa_3}{c(x)="b_0" (c="" b="" \kappa_2\kappa_3\le="" x}{c(x)="0," bc="" the="" stein="" model="" is="" a="" functional="" of="" covariance="" function="" \eqn{\phi}{phi}.="" since="" itself="" indifferent="" for="" scale="" or="" anisotropy="" parameters,="" latter="" must="" be="" given="" only="" submodels.="" see="" below="" general="" comments="" on="" hypermodels.="" first="" parameter,="" \eqn{\kappa_1}{a},="" gives="" number="" subsequent="" models="" that="" build="" \eqn{\phi}{phi};="" \eqn{\kappa_2\ge0}{b="">0}, \eqn{\kappa_3\ge1}{c>=1}. The parameters \eqn{a_0}, \eqn{a_2} and \eqn{b_0} are chosen internally such that \eqn{C} becomes a smooth function. The parameters \eqn{A} and \eqn{B} are the inverse scale parameters for the hypermodel and submodel, respectively.=>
Note that if \eqn{A} and \eqn{B} are not identical, \code{Stein} seldemly works; it may also happen that unsound results are returned without any message of failure.
The algorithm that checks the given parameters knows
only about some few necessary conditions.
Hence it is not ensured that
the Stein-model is a valid covariance function for any
choice of phi and the parameters.
For certain models \eqn{\phi}{phi}, i.e. \code{stable},
\code{whittle}, \code{gencauchy}, and the variogram
model \code{fractalB}
some sufficient conditions are known.
\item \code{steinst1} (non-separabel space time model)
\deqn{C(x, t) = W_{\kappa_1}(y) -
\frac{\langle x, z \rangle t}{(\kappa_1 - 1)(2\kappa_1
+ \kappa_2)} W_{\kappa_1 -1}(y)}{
C(x, t) = W_a(y) -
Here, \eqn{W_{\kappa_1}}{W_a} is the Whittle-Matern model with smoothness parameter \eqn{\kappa_1}{a}; \eqn{\kappa_2}{b} is greater than or equal to the space-time dimension \sQuote{dim}; \eqn{y=\|(x,t)\|}{y = ||(x,t)||}. The components of \eqn{z} are given by \eqn{\kappa_3, \ldots \kappa_{1+\sQuote{dim}}}{c, d, ...}; the norm of \eqn{z} must less than or equal to 1. \item symmetric stable\cr See \code{stable}. \item tent model\cr See \code{power}. \item triangle\cr See \code{power}. \item \code{wave} \deqn{C(x)=\frac{\sin x}x, \quad x>0 \qquad \hbox{and } C(0)=1}{ C(x)=sin(x)/x if x>0 and C(0)=1} This isotropic covariance function is valid only for dimensions less than or equal to 3. It is a special case of the \code{bessel} model (for \eqn{\kappa}{a}\eqn{=0.5}). \item \code{whittlematern} \deqn{C(x)=W_a(x) = 2^{1-\kappa} \Gamma(\kappa)^{-1} x^\kappa K_\kappa(x)}{C(x)=W_a(x) =2^{1-a} Gamma(a)^{-1} x^a K_a(x), } The parameter \eqn{\kappa}{a} is positive. \cr This is the model of choice if the smoothness of a random field is to be parametrised: if \eqn{\kappa\ge}{a>=}\eqn{(2m+1)/2} then the graph is \eqn{m} times differentiable.
The model is a special case of the
\code{hyperbolic} model (for \eqn{\kappa_3=0}{c=0} there).$Let$\rm cov$be a model given in standard notation.
Then the covariance model
applied with arbitrary variance and scale equals$$\rm \qquad variance * \rm cov( (\cdot)/ scale).$$For a given covariance function$\rm cov$the variogram$\gamma$equals$$\gamma(x) = {\rm cov}(0) - {\rm cov}(x).$$Note that the value of the covariance function or variogram
depends also on()$PracticalRange. If the latter isTRUEand the covariance model is isotropic
then the covariance function is internally
rescaled such that cov$(1)\approx 0.05$for standard
parameters (scale==1).
The model and the parameters can be specified by three different
forms; the first
modelis a string;paramis a vector of the formparam=c(mean,variance,nugget,scale,...). (These components
might be given separately or bound to a simple list passed tomodel.)
The first component ofparamis reserved for themeanof a random field and thus ignored in the evaluation of the covariance
function or variogram. The parameters mean, variance, nugget, and scale
must be given in this order; additional
parameters have to be supplied in case of a parametrised class of
models (e.g.hyperbolic, see below),
in the order$\kappa_1$,$\kappa_2$,$\kappa_3$.
Let$\rm cov$be a model given in standard notation.
Then the covariance model
applied with arbitrary variance,
nugget, and scale equals$$\rm \qquad nugget + variance * \rm cov( (\cdot)/ scale).$$Some models allow certain parameter combinations only for certain
dimensions. As any model valid in$d$dimensions is also valid in 1
dimension, the default inCovarianceFctandVariogramisdim=1.modelis a string;paramis a matrix with columns
of the formc(variance, scale, ...). Except that the entries for themeanand thenuggetare missing all explanations given above also apply here.
Each column defines a summand of the nested model. A nugget effect
is indicated byscale=0; possibly additional parameters
are ignored.
modelis a list as specified below;paramis
missing.model = list(l.1, OP.1, l.2, OP.2, ..., l.n)where$n$is at most 10 (exceptcutoff embeddingis
used, seeRFMethods). The listsl.iare all either of the forml.i =
list(model=,var=,kappas=,scale=,method=)or of the forml.i = list(model=,var=,kappas=,aniso=,method=).modelis a string;vargives the variance;scaleis a scalar whereasanisois a$d \times
d$matrix, which is multiplied from the right to the$(n\times d)$matrix of points;
at the transformed points the values of the (isotropic)
random field (with scale 1) are
calculated. The dimension$d$of matrix must match the
number of columns ofx. The models given byl.ican be combined byOP.i="+"orOP.i="*".methodis ignored here; it can be set inCovarianceFct returns a vector of values of the covariance function.
Variogram returns a vector of values of the variogram model.
PrintModelList prints a table of the currently implemented covariance
functions and the matching methods.
PrintModelList returns NULL. GetModelNames returns a list of implemented models
Cauchy models, generalisations and extensions
Hyperbolic model
Iaco-Cesare model
Ma-Stein model
Power model
fractalB
RandomFields,
# the following five model definitions are the same! ## (1) very traditional form (cv <- CovarianceFct(x, model="bessel", c(NA,2,1,5,0.5)))
## (2) traditional form in list notation model <- list(model="bessel", param=c(NA,2,1,5,0.5)) cv - CovarianceFct(x, model=model)
## (3) nested model definition cv - CovarianceFct(x, model="bessel", param=cbind(c(2, 5, 0.5), c(1, 0, 0)))
#### most general notation in form of lists ## (4) isotropic notation model <- list(list(model="bessel", var=2, kappa=0.5, scale=5), "+", list(model="nugget", var=1)) cv - CovarianceFct(x, model=model) ## (5) anisotropic notation model <- list(list(model="bessel", var=2, kappa=0.5, aniso=0.2), "+", list(model="nugget", var=1, aniso=1)) cv - CovarianceFct(as.matrix(x), model=model)
# The model gneitingdiff was defined in RandomFields v1.0. # This isotropic covariance function is valid for dimensions less # than or equal to 3 and has two positive parameters. # It is a class of models with compact support that allows for # smooth parametrisation of the differentiability up to order 6. # The former model `gneitingdiff' must now be coded as gneitingdiff <- function(p){ list(list(m="gneiting", v=p[2], s=p[6]*p[4]), "*", list(m="whittle", k=p[5], v=1.0, s=p[4]), "+", list(m="nugget", v=p[3])) } # and then param <- c(NA, runif(5,max=10)) CovarianceFct(0:100,gneitingdiff(param)) ## instead of formerly CovarianceFct(x,"gneitingdiff",param)
# definition of a hypermodel is more complex
model <- list(list(model="mastein", var=1,
aniso=c(1, -0.5, 0, 0), kappa=c(1, 0.5, 1.5)),
"(",
list(model="exp", var=1, aniso=c(0, 0, ,0, 1)))
CovarianceFct(cbind(0:10, 0:10), model=model)